This module is created for demo purpose,
which will return factorial of given number

For a full description, how to create package
[project page](https://packaging.python.org/en/latest/tutorials/packaging-projects/).